==> kwebwatch-0.6.tar.gz: kwebwatch-0.6/kwebwatch/moc_mw.cpp <==
/****************************************************************************
** MainWidget meta object code from reading C++ file 'mainwidget.h'
**
** Created: Thu Oct 8 17:51:23 1998
**      by: The Qt Meta Object Compiler ($Revision: 2.18 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#if !defined(Q_MOC_OUTPUT_REVISION)
#define Q_MOC_OUTPUT_REVISION 2
#elif Q_MOC_OUTPUT_REVISION != 2
#error Moc format conflict - please regenerate all moc files
#endif

#include "mainwidget.h"
#include <qmetaobj.h>


const char *MainWidget::className() const
{
    return "MainWidget";
}

QMetaObject *MainWidget::metaObj = 0;

void MainWidget::initMetaObject()
{
    if ( metaObj )
	return;
    if ( strcmp(KTopLevelWidget::className(), "KTopLevelWidget") != 0 )
	badSuperclassWarning("MainWidget","KTopLevelWidget");
    if ( !KTopLevelWidget::metaObject() )
	KTopLevelWidget::initMetaObject();
    typedef void(MainWidget::*m1_t0)();
    typedef void(MainWidget::*m1_t1)();
    typedef void(MainWidget::*m1_t2)();
    typedef void(MainWidget::*m1_t3)(const char*);
    typedef void(MainWidget::*m1_t4)();
    typedef void(MainWidget::*m1_t5)();
    typedef void(MainWidget::*m1_t6)(QPoint);
    typedef void(MainWidget::*m1_t7)();
    typedef bool(MainWidget::*m1_t8)(class UrlItem*);
    typedef void(MainWidget::*m1_t9)();
    typedef void(MainWidget::*m1_t10)(UrlItem*,bool);
    typedef void(MainWidget::*m1_t11)();
    typedef void(MainWidget::*m1_t12)(const char*);
    typedef void(MainWidget::*m1_t13)();
    typedef void(MainWidget::*m1_t14)();
    typedef void(MainWidget::*m1_t15)();
    typedef void(MainWidget::*m1_t16)();
    m1_t0 v1_0 = &MainWidget::AddUrl;
    m1_t1 v1_1 = &MainWidget::CheckAllUrls;
    m1_t2 v1_2 = &MainWidget::CheckUrlsIfTime;
    m1_t3 v1_3 = &MainWidget::AddItemToListBox;
    m1_t4 v1_4 = &MainWidget::Delete;
    m1_t5 v1_5 = &MainWidget::ShowProperties;
    m1_t6 v1_6 = &MainWidget::ShowPopupMenu;
    m1_t7 v1_7 = &MainWidget::CheckSelectedNow;
    m1_t8 v1_8 = &MainWidget::CheckNow;
    m1_t9 v1_9 = &MainWidget::LaunchSelected;
    m1_t10 v1_10 = &MainWidget::UpdateListBox;
    m1_t11 v1_11 = &MainWidget::ShowOptions;
    m1_t12 v1_12 = &MainWidget::ChangeDefaultBrowserPaths;
    m1_t13 v1_13 = &MainWidget::MarkSelectedRead;
    m1_t14 v1_14 = &MainWidget::DockToPanel;
    m1_t15 v1_15 = &MainWidget::HelpAbout;
    m1_t16 v1_16 = &MainWidget::HelpContents;
    QMetaData *slot_tbl = new QMetaData[17];
    slot_tbl[0].name = "AddUrl()";
    slot_tbl[1].name = "CheckAllUrls()";
    slot_tbl[2].name = "CheckUrlsIfTime()";
    slot_tbl[3].name = "AddItemToListBox(const char*)";
    slot_tbl[4].name = "Delete()";
    slot_tbl[5].name = "ShowProperties()";
    slot_tbl[6].name = "ShowPopupMenu(QPoint)";
    slot_tbl[7].name = "CheckSelectedNow()";
    slot_tbl[8].name = "CheckNow(class UrlItem*)";
    slot_tbl[9].name = "LaunchSelected()";
    slot_tbl[10].name = "UpdateListBox(UrlItem*,bool)";
    slot_tbl[11].name = "ShowOptions()";
    slot_tbl[12].name = "ChangeDefaultBrowserPaths(const char*)";
    slot_tbl[13].name = "MarkSelectedRead()";
    slot_tbl[14].name = "DockToPanel()";
    slot_tbl[15].name = "HelpAbout()";
    slot_tbl[16].name = "HelpContents()";
    slot_tbl[0].ptr = *((QMember*)&v1_0);
    slot_tbl[1].ptr = *((QMember*)&v1_1);
    slot_tbl[2].ptr = *((QMember*)&v1_2);
    slot_tbl[3].ptr = *((QMember*)&v1_3);
    slot_tbl[4].ptr = *((QMember*)&v1_4);
    slot_tbl[5].ptr = *((QMember*)&v1_5);
    slot_tbl[6].ptr = *((QMember*)&v1_6);
    slot_tbl[7].ptr = *((QMember*)&v1_7);
    slot_tbl[8].ptr = *((QMember*)&v1_8);
    slot_tbl[9].ptr = *((QMember*)&v1_9);
    slot_tbl[10].ptr = *((QMember*)&v1_10);
    slot_tbl[11].ptr = *((QMember*)&v1_11);
    slot_tbl[12].ptr = *((QMember*)&v1_12);
    slot_tbl[13].ptr = *((QMember*)&v1_13);
    slot_tbl[14].ptr = *((QMember*)&v1_14);
    slot_tbl[15].ptr = *((QMember*)&v1_15);
    slot_tbl[16].ptr = *((QMember*)&v1_16);
    metaObj = new QMetaObject( "MainWidget", "KTopLevelWidget",
	slot_tbl, 17,
	0, 0 );
}

==> kwebwatch-0.71.tar.gz: kwebwatch-0.71/kwebwatch/moc_mw.cpp <==
/****************************************************************************
** MainWidget meta object code from reading C++ file 'mainwidget.h'
**
** Created: Wed Dec 16 21:47:45 1998
**      by: The Qt Meta Object Compiler ($Revision: 2.18 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#if !defined(Q_MOC_OUTPUT_REVISION)
#define Q_MOC_OUTPUT_REVISION 2
#elif Q_MOC_OUTPUT_REVISION != 2
#error Moc format conflict - please regenerate all moc files
#endif

#include "mainwidget.h"
#include <qmetaobj.h>


const char *MainWidget::className() const
{
    return "MainWidget";
}

QMetaObject *MainWidget::metaObj = 0;

void MainWidget::initMetaObject()
{
    if ( metaObj )
	return;
    if ( strcmp(KTopLevelWidget::className(), "KTopLevelWidget") != 0 )
	badSuperclassWarning("MainWidget","KTopLevelWidget");
    if ( !KTopLevelWidget::metaObject() )
	KTopLevelWidget::initMetaObject();
    typedef void(MainWidget::*m1_t0)();
    typedef void(MainWidget::*m1_t1)();
    typedef void(MainWidget::*m1_t2)();
    typedef void(MainWidget::*m1_t3)(const char*);
    typedef void(MainWidget::*m1_t4)();
    typedef void(MainWidget::*m1_t5)();
    typedef void(MainWidget::*m1_t6)(QPoint);
    typedef void(MainWidget::*m1_t7)();
    typedef bool(MainWidget::*m1_t8)(class UrlItem*,bool);
    typedef void(MainWidget::*m1_t9)();
    typedef void(MainWidget::*m1_t10)(UrlItem*,bool);
    typedef void(MainWidget::*m1_t11)();
    typedef void(MainWidget::*m1_t12)(const char*);
    typedef void(MainWidget::*m1_t13)();
    typedef void(MainWidget::*m1_t14)();
    typedef void(MainWidget::*m1_t15)();
    typedef void(MainWidget::*m1_t16)(UrlItem*);
    typedef void(MainWidget::*m1_t17)();
    typedef void(MainWidget::*m1_t18)();
    m1_t0 v1_0 = &MainWidget::AddUrl;
    m1_t1 v1_1 = &MainWidget::CheckAllUrls;
    m1_t2 v1_2 = &MainWidget::CheckUrlsIfTime;
    m1_t3 v1_3 = &MainWidget::AddItemToListBox;
    m1_t4 v1_4 = &MainWidget::Delete;
    m1_t5 v1_5 = &MainWidget::ShowProperties;
    m1_t6 v1_6 = &MainWidget::ShowPopupMenu;
    m1_t7 v1_7 = &MainWidget::CheckSelectedNow;
    m1_t8 v1_8 = &MainWidget::CheckNow;
    m1_t9 v1_9 = &MainWidget::LaunchSelected;
    m1_t10 v1_10 = &MainWidget::UpdateListBox;
    m1_t11 v1_11 = &MainWidget::ShowOptions;
    m1_t12 v1_12 = &MainWidget::ChangeDefaultBrowserPaths;
    m1_t13 v1_13 = &MainWidget::DockToPanel;
    m1_t14 v1_14 = &MainWidget::HelpAbout;
    m1_t15 v1_15 = &MainWidget::HelpContents;
    m1_t16 v1_16 = &MainWidget::MarkAsRead;
    m1_t17 v1_17 = &MainWidget::MarkAllRead;
    m1_t18 v1_18 = &MainWidget::MarkSelectedRead;
    QMetaData *slot_tbl = new QMetaData[19];
    slot_tbl[0].name = "AddUrl()";
    slot_tbl[1].name = "CheckAllUrls()";
    slot_tbl[2].name = "CheckUrlsIfTime()";
    slot_tbl[3].name = "AddItemToListBox(const char*)";
    slot_tbl[4].name = "Delete()";
    slot_tbl[5].name = "ShowProperties()";
    slot_tbl[6].name = "ShowPopupMenu(QPoint)";
    slot_tbl[7].name = "CheckSelectedNow()";
    slot_tbl[8].name = "CheckNow(class UrlItem*,bool)";
    slot_tbl[9].name = "LaunchSelected()";
    slot_tbl[10].name = "UpdateListBox(UrlItem*,bool)";
    slot_tbl[11].name = "ShowOptions()";
    slot_tbl[12].name = "ChangeDefaultBrowserPaths(const char*)";
    slot_tbl[13].name = "DockToPanel()";
    slot_tbl[14].name = "HelpAbout()";
    slot_tbl[15].name = "HelpContents()";
    slot_tbl[16].name = "MarkAsRead(UrlItem*)";
    slot_tbl[17].name = "MarkAllRead()";
    slot_tbl[18].name = "MarkSelectedRead()";
    slot_tbl[0].ptr = *((QMember*)&v1_0);
    slot_tbl[1].ptr = *((QMember*)&v1_1);
    slot_tbl[2].ptr = *((QMember*)&v1_2);
    slot_tbl[3].ptr = *((QMember*)&v1_3);
    slot_tbl[4].ptr = *((QMember*)&v1_4);
    slot_tbl[5].ptr = *((QMember*)&v1_5);
    slot_tbl[6].ptr = *((QMember*)&v1_6);
    slot_tbl[7].ptr = *((QMember*)&v1_7);
    slot_tbl[8].ptr = *((QMember*)&v1_8);
    slot_tbl[9].ptr = *((QMember*)&v1_9);
    slot_tbl[10].ptr = *((QMember*)&v1_10);
    slot_tbl[11].ptr = *((QMember*)&v1_11);
    slot_tbl[12].ptr = *((QMember*)&v1_12);
    slot_tbl[13].ptr = *((QMember*)&v1_13);
    slot_tbl[14].ptr = *((QMember*)&v1_14);
    slot_tbl[15].ptr = *((QMember*)&v1_15);
    slot_tbl[16].ptr = *((QMember*)&v1_16);
    slot_tbl[17].ptr = *((QMember*)&v1_17);
    slot_tbl[18].ptr = *((QMember*)&v1_18);
    metaObj = new QMetaObject( "MainWidget", "KTopLevelWidget",
	slot_tbl, 19,
	0, 0 );
}
